@@ -206,6 +206,13 @@ def test_version_build_diff_compare():
     assert not res
 
 
+def test_version_hash_compare():
+    res = utils.version_compare("3.1.2", "0", None, None, "acb672b6a179567632e032f547582f30fa2f4aa7")
+    assert not res
+    res = utils.version_compare("3.1.2", "acb672b6a179567632e032f547582f30fa2f4aa7", "acb672b6a179567632e032f547582f30fa2f4aa7", None, None)
+    assert not res
+
+
 def test_parse_uri():
     vendor, package, version, cve_type = utils.parse_cpe(
         "cpe:2.3:o:google:android:9.0:*:*:*:*:*:*:*"
