@@ -58,7 +58,7 @@ def build_args():
         action="store_true",
         default=False,
         dest="only_osv",
-        help="Use only OSV as the source.",
+        help="Use only OSV as the source. Use with --cache.",
     )
     parser.add_argument(
         "--sync",
