@@ -1,9 +1,10 @@
-import string
 import importlib
 import re
+import string
 from datetime import date, datetime
 from enum import Enum
 
+from cvss import CVSS3
 from packageurl import PackageURL
 from semver import VersionInfo
 
@@ -561,7 +562,7 @@ def get_default_cve_data(severity):
     """
     Return some default CVE metadata for the given severity
     :param severity: Severity
-    :return: score, vectorString
+    :return: score, severity, vectorString, attackComplexity
     """
     vectorString = "CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:H/I:H/A:H"
     score = 9.0
@@ -582,6 +583,16 @@ def get_default_cve_data(severity):
     return score, severity, vectorString, attackComplexity
 
 
+def get_cvss3_from_vector(vector):
+    """
+    Return CVE metadata for the given vector
+    :param vector: Vector
+    :return: CVSS3 parsed and converted to json
+    """
+    c = CVSS3(vector)
+    return c.as_json()
+
+
 def convert_to_occurrence(datas):
     """Method to parse raw search result and convert to Vulnerability occurence
 
